import { NavBar } from "@civicactions/data-catalog-components";
import React from "react";
import Inicio from "../../components/First";
import PiePag from "../../components/Footer";
import { Link } from '@reach/router';
import links from "../../assets/menu.json";

/**
 * Vista para el Tag que está en el footer "DESARROLLADORES"
 */

const Layout = () => {
    return (
        <Inicio title="Desarrolladores">
            <NavBar
                navItems={links.main.map(item => (
                <Link activeclassname="active" to={item.url}>
                    {item.label}
                </Link>
                ))}
            />
            
            <div id="main-wrapper">
                <div id="main" className="main container">
                    <div className="main-row uk-padding-large">
                        <section>
                            <h1 style={{color:"black"}} className="page-header">Desarrolladores</h1>
                            <p>A continuación te presentamos una guía básica de herramientas 
                                a usar para el tratamiento de datos.  Si tienes dudas o te 
                                gustaría aportar código, escríbenos en la sección de 
                                <a href="/contact"> Contacto </a>
                                o directamente a nuestro correo  
                                <a href="mailto:datosabiertos@puebla.gob.mx"> datosabiertos@puebla.gob.mx </a>
                                con tema "Sección para desarrolladores".
                                </p>
                                <p>
                                    Las herramientas que te recomendamos:
                                </p>

                                <h3>Limpieza de datos</h3>
                                <ul>
                                    <li>
                                        <a href="http://openrefine.org">OpenRefine</a>
                                    </li>
                                </ul>

                                <h3>Extracción de datos</h3>
                                <ul>
                                    <li>
                                        <a href="https://www.import.io/">import.io</a>
                                    </li>
                                </ul>
                                <h3>Mapas de datos</h3>
                                <ul>
                                    <li>
                                        <a href="https://developers.arcgis.com/javascript/">ArcGIS</a>
                                    </li>
                                    <li>
                                        <a href="https://leafletjs.com/">Leaflet</a>
                                    </li>
                                    <li>
                                        <a href="https://carto.com/">Carto</a>
                                    </li>
                                </ul>

                                <h3>DKAN API FAQs</h3>
                                <blockquote>
                                    <p>
                                    Si está buscando cargar grandes cantidades de datos en el sitio, la API puede ser el mejor método para usar.
                                    <br />
                                    Puede encontrar la documentación de la API aquí:  
                                    <a href="http://dkan.readthedocs.io/en/latest/apis/index.html">http://dkan.readthedocs.io/en/latest/apis/index.html. </a>
                                     Los primeros dos listados son lo que necesita: la 
                                    <a href="https://dkan.readthedocs.io/en/latest/apis/rest-api.html">"Dataset REST API"</a> y
                                    <a href="http://dkan.readthedocs.io/en/latest/apis/datastore-api.html"> "DataStore api".</a>
                                      
                                    </p>
                                </blockquote>
                                <h3>¿Cómo consumir los datos abiertos vía API desde C#?</h3>
                                <p>Consideraciones</p>
                                <ul>
                                    <li>Toda la información disponible a través de la DKAN API REST en este portal, tiene un 
                                        <strong>Identificador de Recursos Uniforme </strong>
                                        (
                                            <em>URI - Uniform Resource Identifier</em>
                                        ), lo que permite obtener la información en la misma <strong> URL </strong> publicada (nivel 5 estrellas según la escala de
                                         Tim Berners Lee).
                                    </li>
                                    <br />
                                    <li>
                                        Toda la información que devuelve el <strong> API </strong> es en formato <strong> JSON </strong> o <strong>geoJSON</strong> según corresponda.
                                    </li>
                                </ul>

                                <p><strong>Ejemplo <em>conocer la afluencia de visitantes por destino turístico en el estado de Puebla en los últimos años.</em></strong></p>
                                <p><strong>Los pasos para consumir la información de manera automática serían los siguientes:</strong></p>
                                <p><strong>1.- Identificar que el <em>dataset</em> y recursos que necesita existan en el pórtal de Datos Abiertos.</strong></p>
                                <p> <img src="##" alt="Información del recurso" /></p>
                                <p> <strong> 2.- Para obtener el URL y consumir los datos, da <em> click </em>en el enlace <em> API </em> situado en la barra lateral izquierda (sidebar).</strong></p>
                                <p> <strong> 3.- Esta pantalla le mostrará tpda la información al respecto:</strong>
                                    <br />
                                    <img src="#" alt="Ejemplo de consulta" />
                                </p>
                                <p><strong>4.- Al darle <em>click </em>al enlace, te mostrará la información en formato JSON, copia el contenido y puedes crear una clase con esta estructura usando la opción 
                                de <em>Pegado Especial </em> de VS 2022, como se muestra en la siguiente imágen: </strong>
                                <br />
                                <img src="#" alt="Pegado Especial" />
                                </p>
                                <p><strong>5.- Tu clase quedaría así: </strong>
                                <br />
                                <img src="#" alt="Ejemplo de clase" />
                                </p>

                                <blockquote>
                                    <p>
                                        <code>
                                            <br />
                                            using...##Codigo que falta
                                            <br />
                                            
                                        </code>
                                    </p>
                                </blockquote>
                                <p><strong>6.- Copia el <em>link </em> e insértalo en una constante en tu código de c#</strong></p>
                                <blockquote>
                                    <p>
                                        <code>
                                            <br />
                                            *//si quieres obtener todos los resultados agrega al url el parámetro: &limit=0*
                                            <br />
                                            public const string UrlAfluenciaTuristica =
                                            <br />
                                            "http://datos.puebla.gob.mx/api/action/datastore/search.json?resource_id=ca509a49-cd8a-46d4-9474-7df7808b8919";(Va a cambiar)
                                        </code>
                                    </p>
                                </blockquote>
                                <p><strong>7.- Crea tu método para obtener y deserializar el archivo JSON por medio de un HttpWebRequest, quedaría algo así:</strong></p>
                                <blockquote>
                                    <p>
                                        <code>
                                            <br />
                                            Pedazo de codigo
                                        </code>
                                    </p>
                                </blockquote>
                                <p><strong>El código donde realizas la petición y obtienes un resultado sería algo así: </strong></p>
                                <blockquote>
                                    <p>
                                        <code>
                                            <br />
                                            Pedazo de código
                                        </code>
                                    </p>
                                </blockquote>
                                <p><strong>El resultado en consola se ve así: </strong>
                                    <br />
                                    <img src="#" alt="Resultado en consola" />
                                </p>
                                <p><strong>8.- Si quieres descargar este ejemplo, ve al repositorio de <a href="https://github.com/TonyRojasGil/Prometeo"><em>GitHub</em></a></strong></p>
                                <p>Si te gustó esta guía, comparte en tus redes sociales este ejemplo para hacer uso de los Datos Abiertos del gobierno del estado de Puebla etiquetando a @CETGAPue.</p>

                        </section>
                        

                        

                    </div>

                </div>
            </div>

            <PiePag></PiePag>
        </Inicio>
    )
}
export default Layout;