import React from "react";
import { Link } from "@reach/router";
import Loader from "react-loader-advanced";
import LoadingSpin from "react-loading-spin";
import {
  ApiDocs,
  Organization
} from "@civicactions/data-catalog-components";
import config from "../../assets/config";
import orgs from "../../assets/publishers";
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import axios from 'axios';
//import Layout from "../../components/Layout";
import Inicio from "../../components/First";
import { NavBar, Header} from "@civicactions/data-catalog-components";
import links from "../../assets/menu.json";
import image from "../../assets/images/logo-interna.png";
import PiePag from "../../components/Footer";




const ApiDocsSpecific = ({ id, location }) => {
  const { state } = location;
  const [item, setItem] = React.useState(state && state.dataset ? state.dataset : {});
  const [loading, setLoading] = React.useState(true);
  React.useEffect(() => {
    if(state && state.dataset) {
      setLoading(false);
    } else {
      axios.get(`${process.env.REACT_APP_ROOT_URL}/metastore/schemas/dataset/items/${id}?show-reference-ids`)
      .then((res) => {
        setItem(res.data);
        setLoading(false);
      })
    }
  }, [id, state])


    const orgName = "publisher" in item && item.publisher.data ? item.publisher.data.name : "";
    const orgDetails = orgs.filter(org => orgName === org.name);
    const orgImage = orgDetails.length && orgDetails[0].imageUrl ? orgDetails[0].imageUrl : "";
    const orgDesc = orgDetails.length && orgDetails[0].description ? orgDetails[0].description : "";
    let renderOrg;
    if(orgDetails.length > 0 && orgDetails[0].imageUrl) {
      renderOrg = <Organization name={orgName} imageUrl={orgImage} description={orgDesc}/>;
    } else {
      renderOrg = <Organization name={orgName} description={orgDesc}/>;
    }
  return (
    <Inicio title="Dataset API">
      <div className="uk-grid" data-uk-grid>
                <NavBar
                navItems={links.main.map(item => (
                <Link activeClassName="active" to={item.url}>
                    {item.label}
                </Link>
                ))}
                />
                <Header logo={image} slogan={config.slogan} customClasses={config.container}>jsdsadjio</Header>
                
      </div>

      <div className={`dc-page container dc-dataset-page ${config.container}`}>
        
        <Loader
            backgroundStyle={{ backgroundColor: "#f9fafb" }}
            foregroundStyle={{ backgroundColor: "#f9fafb" }}
            show={loading}
            message={
              <LoadingSpin width={"3px"} primaryColor={"#007BBC"} />
            }
          >

    
        
          <div className="row">

              <div className="col-md-3 col-sm-12">
                {renderOrg}
                <div className="dc-block-wrapper">
                  <FontAwesomeIcon
                    icon={['fas', 'arrow-left']}
                    size="1x"
                    aria-hidden="true"
                    role="presentation"
                  />
                  Regresar al{" "}
                  <Link
                    to={`/dataset/${id}`}
                    state={{dataset: {...item}}}
                  >
                    dataset
                  </Link>
                  .
                </div>
              </div>
              <div className="results-list col-md-9 col-sm-12">
                <h1>{item.title}</h1>
                <ApiDocs
                  endpoint={
                    `${process.env.REACT_APP_ROOT_URL}` +
                    "/metastore/schemas/dataset/items/" +
                    id +
                    "/docs"
                  }
                />
              </div>

          </div>
        </Loader>

                
      </div>
      <PiePag></PiePag>
    </Inicio>
  );
}

export default ApiDocsSpecific;
